@@ -10,7 +10,7 @@ def series_name_key(s):
 
 
 def action(ns):
-    print ns.term.bold_magenta(u"Series you are currently watching")
+    print ns.t.bold_magenta(u"Series you are currently watching")
     print u""
 
     now = datetime.datetime.now()
@@ -21,7 +21,7 @@ def action(ns):
 
     series_list = ns.series.list_series()
 
-    episodes_legend = format_episodes_count_legend(ns.term)
+    episodes_legend = format_episodes_count_legend(ns.t)
 
     if series_list:
         for series in sorted(series_list, key=series_name_key):
@@ -31,17 +31,17 @@ def action(ns):
 
             if episodes is not None:
                 episodes_count, _ = format_episodes_count(
-                    ns.term, series_dao, has_aired, episodes)
+                    ns.t, series_dao, has_aired, episodes)
 
-            print ns.term.bold_cyan(
+            print ns.t.bold_cyan(
                 u"{0[series_name]} (id: {0[id]})".format(series))
 
             if episodes_count:
-                print ns.term.cyan(
+                print ns.t.cyan(
                     u"  Episodes ({0}): {1}".format(
                         episodes_legend, episodes_count))
     else:
-        print ns.term.bold_red("You are not watching any series")
+        print ns.t.bold_red("You are not watching any series")
 
     return 0
 
